﻿using System.Collections.ObjectModel;
using System.Device.Location;
using System.Threading.Tasks;
using System.Windows.Input;
using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Command;
using Microsoft.Phone.Maps.Services;
using Wp7nl.Utilities;

namespace NavigationDemo.Logic.ViewModels
{
  public class GeocodeViewModel : ViewModelBase
  {
    public GeocodeViewModel()
    {
      MapLocations = new ObservableCollection<MapLocation>();
    }

    public ObservableCollection<MapLocation> MapLocations { get; set; }

    private string searchText;
    public string SearchText
    {
      get { return searchText; }
      set
      {
        if (searchText != value)
        {
          searchText = value;
          RaisePropertyChanged(() => SearchText);
        }
      }
    }

    private MapLocation selectedLocation;
    public MapLocation SelectedLocation
    {
      get { return selectedLocation; }
      set
      {
        if (selectedLocation != value)
        {
          selectedLocation = value;
          RaisePropertyChanged(() => SelectedLocation);
        }
      }
    }

    public async Task SearchLocation()
    {
      MapLocations.Clear();
      SelectedLocation = null;
      var geoCoder = new GeocodeQuery { SearchTerm = SearchText, 
        GeoCoordinate = new GeoCoordinate() };
      MapLocations.AddRange(await geoCoder.GetMapLocationsAsync());
    }

    public ICommand SearchLocationCommand
    {
      get
      {
        return new RelayCommand(async () => await SearchLocation());
      }
    }
  }
}
